@@ -531,7 +531,8 @@ int main(void)
                             /* Wrap long lines */
                             char *pos = line;
                             while (*pos && line_num < data_end_row) {
-                                int chunk_len = (strlen(pos) > max_width) ? max_width : strlen(pos);
+                                size_t remaining = strlen(pos);
+                                int chunk_len = (remaining > (size_t)max_width) ? max_width : (int)remaining;
                                 mvwprintw(stdscr, line_num, 2, "%.*s", chunk_len, pos);
                                 pos += chunk_len;
                                 line_num++;
@@ -561,13 +562,15 @@ int main(void)
                             /* Wrap long lines */
                             char *pos = line;
                             while (*pos && line_num < data_end_row) {
-                                int chunk_len = (strlen(pos) > max_width) ? max_width : strlen(pos);
+                                size_t remaining = strlen(pos);
+                                int chunk_len = (remaining > (size_t)max_width) ? max_width : (int)remaining;
                                 mvwprintw(stdscr, line_num, 2, "%.*s", chunk_len, pos);
                                 pos += chunk_len;
                                 line_num++;
                             }
                         }
                         line = strtok(NULL, "\n");
+                    }
                     free(output_copy);
                 } else {
                     mvwprintw(stdscr, 3, 2, "Memory allocation error");
